nxp-pac

Crates

git

Versions

mimxrt1064

Flavors

Trig0Ctrl

Struct Trig0Ctrl 

#[repr(transparent)]
pub struct Trig0Ctrl(pub u32);
ETC_TRIG Control Register

Tuple Fields

0: u32

Implementations

Source

impl Trig0Ctrl

pub const fn sw_trig(&self) -> Trig0CtrlSwTrig

Software trigger. This field is self-clearing.

pub const fn set_sw_trig(&mut self, val: Trig0CtrlSwTrig)

Software trigger. This field is self-clearing.

pub const fn trig_mode(&self) -> Trig0CtrlTrigMode

Trigger mode selection.

pub const fn set_trig_mode(&mut self, val: Trig0CtrlTrigMode)

Trigger mode selection.

pub const fn trig_chain(&self) -> Trig0CtrlTrigChain

The number of segments inside the trigger chain of TRIGa.

pub const fn set_trig_chain(&mut self, val: Trig0CtrlTrigChain)

The number of segments inside the trigger chain of TRIGa.

pub const fn trig_priority(&self) -> u8

External trigger priority, 7 is highest priority, while 0 is lowest

pub const fn set_trig_priority(&mut self, val: u8)

External trigger priority, 7 is highest priority, while 0 is lowest

pub const fn sync_mode(&self) -> Trig0CtrlSyncMode

Trigger synchronization mode selection

pub const fn set_sync_mode(&mut self, val: Trig0CtrlSyncMode)

Trigger synchronization mode selection