#[repr(transparent)]pub struct Trig1Ctrl(pub u32);Expand description
ETC_TRIG Control Register
Tuple Fields
0: u32Implementations
Sourceimpl Trig1Ctrl
impl Trig1Ctrl
Sourcepub const fn sw_trig(&self) -> Trig1CtrlSwTrig
pub const fn sw_trig(&self) -> Trig1CtrlSwTrig
Software trigger. This field is self-clearing.
Sourcepub const fn set_sw_trig(&mut self, val: Trig1CtrlSwTrig)
pub const fn set_sw_trig(&mut self, val: Trig1CtrlSwTrig)
Software trigger. This field is self-clearing.
Sourcepub const fn trig_mode(&self) -> Trig1CtrlTrigMode
pub const fn trig_mode(&self) -> Trig1CtrlTrigMode
Trigger mode selection.
Sourcepub const fn set_trig_mode(&mut self, val: Trig1CtrlTrigMode)
pub const fn set_trig_mode(&mut self, val: Trig1CtrlTrigMode)
Trigger mode selection.
Sourcepub const fn trig_chain(&self) -> Trig1CtrlTrigChain
pub const fn trig_chain(&self) -> Trig1CtrlTrigChain
The number of segments inside the trigger chain of TRIGa.
Sourcepub const fn set_trig_chain(&mut self, val: Trig1CtrlTrigChain)
pub const fn set_trig_chain(&mut self, val: Trig1CtrlTrigChain)
The number of segments inside the trigger chain of TRIGa.
Sourcepub const fn trig_priority(&self) -> u8
pub const fn trig_priority(&self) -> u8
External trigger priority, 7 is highest priority, while 0 is lowest
Sourcepub const fn set_trig_priority(&mut self, val: u8)
pub const fn set_trig_priority(&mut self, val: u8)
External trigger priority, 7 is highest priority, while 0 is lowest
Sourcepub const fn sync_mode(&self) -> Trig1CtrlSyncMode
pub const fn sync_mode(&self) -> Trig1CtrlSyncMode
Trigger synchronization mode selection
Sourcepub const fn set_sync_mode(&mut self, val: Trig1CtrlSyncMode)
pub const fn set_sync_mode(&mut self, val: Trig1CtrlSyncMode)
Trigger synchronization mode selection